@@ -1,17 +1,16 @@
-// Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
+// Copyright (C) 2023 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 
 #include "widget.h"
 
-#include <QtMultimedia/QAudioDevice>
-#include <QtMultimedia/QMediaDevices>
-#include <QtWidgets/QApplication>
-#include <QtWidgets/QMessageBox>
+#include <QApplication>
+#include <QAudioDevice>
+#include <QMediaDevices>
+#include <QMessageBox>
 
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-
     const QAudioDevice inputDevice = QMediaDevices::defaultAudioInput();
     if (inputDevice.isNull()) {
         QMessageBox::warning(nullptr, "audio",
@@ -20,6 +19,7 @@ int main(int argc, char *argv[])
     }
 
     Widget w(inputDevice);
+    w.resize(800, 600);
     w.show();
     
     return a.exec();
