@@ -1,10 +1,11 @@
-// Copyright (C) 2016 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
+// Copyright (C) 2023 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR BSD-3-Clause
 
 #include "chart.h"
-#include <QtWidgets/QGesture>
-#include <QtWidgets/QGraphicsScene>
-#include <QtWidgets/QGraphicsView>
+
+#include <QGesture>
+#include <QGraphicsScene>
+#include <QGraphicsView>
 
 Chart::Chart(QGraphicsItem *parent, Qt::WindowFlags wFlags)
     : QChart(QChart::ChartTypeCartesian, parent, wFlags)
@@ -15,11 +16,6 @@ Chart::Chart(QGraphicsItem *parent, Qt::WindowFlags wFlags)
     grabGesture(Qt::PinchGesture);
 }
 
-Chart::~Chart()
-{
-
-}
-
 //![1]
 bool Chart::sceneEvent(QEvent *event)
 {
@@ -31,12 +27,12 @@ bool Chart::sceneEvent(QEvent *event)
 bool Chart::gestureEvent(QGestureEvent *event)
 {
     if (QGesture *gesture = event->gesture(Qt::PanGesture)) {
-        QPanGesture *pan = static_cast<QPanGesture *>(gesture);
+        auto pan = static_cast<QPanGesture *>(gesture);
         QChart::scroll(-(pan->delta().x()), pan->delta().y());
     }
 
     if (QGesture *gesture = event->gesture(Qt::PinchGesture)) {
-        QPinchGesture *pinch = static_cast<QPinchGesture *>(gesture);
+        auto pinch = static_cast<QPinchGesture *>(gesture);
         if (pinch->changeFlags() & QPinchGesture::ScaleFactorChanged)
             QChart::zoom(pinch->scaleFactor());
     }
