@@ -20,7 +20,7 @@ QT_BEGIN_NAMESPACE
 
 class QLogValueAxis;
 
-class Q_CHARTS_PRIVATE_EXPORT PolarChartLogValueAxisAngular : public PolarChartAxisAngular
+class Q_CHARTS_EXPORT PolarChartLogValueAxisAngular : public PolarChartAxisAngular
 {
     Q_OBJECT
 public:
