@@ -1,31 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Charts module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 or (at your option) any later version
-** approved by the KDE Free Qt Foundation. The licenses are as published by
-** the Free Software Foundation and appearing in the file LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2021 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtCharts/QAbstractAxis>
 #include <private/qabstractaxis_p.h>
@@ -49,7 +23,7 @@ QT_BEGIN_NAMESPACE
 */
 /*!
     \qmltype AbstractAxis
-    \instantiates QAbstractAxis
+    \nativetype QAbstractAxis
     \inqmlmodule QtCharts
 
     \brief A base type used for specialized axis types.
@@ -1078,22 +1052,22 @@ QAbstractAxisPrivate::~QAbstractAxisPrivate()
 {
 }
 
-void QAbstractAxisPrivate::setAlignment( Qt::Alignment alignment)
+void QAbstractAxisPrivate::setAlignment(Qt::Alignment alignment)
 {
-    switch(alignment) {
-        case Qt::AlignTop:
-        case Qt::AlignBottom:
+    switch (alignment) {
+    case Qt::AlignTop:
+    case Qt::AlignBottom:
         m_orientation = Qt::Horizontal;
         break;
-        case Qt::AlignLeft:
-        case Qt::AlignRight:
+    case Qt::AlignLeft:
+    case Qt::AlignRight:
         m_orientation = Qt::Vertical;
         break;
-        default:
-        qWarning()<<"No alignment specified !";
+    default:
+        qWarning("No alignment specified !");
         break;
-    };
-    m_alignment=alignment;
+    }
+    m_alignment = alignment;
 }
 
 void QAbstractAxisPrivate::setLabelsTruncated(bool labelsTruncated)
@@ -1156,7 +1130,7 @@ void QAbstractAxisPrivate::initializeGraphics(QGraphicsItem* parent)
 void QAbstractAxisPrivate::initializeAnimations(QChart::AnimationOptions options, int duration,
                                                 QEasingCurve &curve)
 {
-    ChartAxisElement *axis = m_item.data();
+    ChartAxisElement *axis = m_item.get();
     Q_ASSERT(axis);
     if (axis->animation())
         axis->animation()->stopAndDestroyLater();
