@@ -1,6 +1,8 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
+#undef QT_NO_FOREACH // this file contains unported legacy Q_FOREACH uses
+
 #include <QtCharts/QAbstractBarSeries>
 #include <private/qabstractbarseries_p.h>
 #include <QtCharts/QBarSet>
@@ -31,8 +33,7 @@ QT_BEGIN_NAMESPACE
     If a QValueAxis is used instead of QBarCategoryAxis for the main bar axis, the bars are
     grouped around the index value of the category.
 
-    See the \l {BarChart Example} {bar chart example} to learn how to use the QBarSeries class
-    to create a simple bar chart.
+    See the \l {Charts with Widgets Gallery} to learn how to use the QBarSeries class to create a simple bar chart.
     \image examples_barchart.png
 
     \sa QBarSet, QBarSeries, QStackedBarSeries, QPercentBarSeries
@@ -40,7 +41,7 @@ QT_BEGIN_NAMESPACE
 */
 /*!
     \qmltype AbstractBarSeries
-    \instantiates QAbstractBarSeries
+    \nativetype QAbstractBarSeries
     \inqmlmodule QtCharts
 
     \inherits AbstractSeries
@@ -59,7 +60,7 @@ QT_BEGIN_NAMESPACE
 
     The following QML code snippet shows how to use the BarSeries and BarCategoryAxis type
     to create a simple bar chart:
-    \snippet qmlchart/qml/qmlchart/View6.qml 1
+    \snippet qmlchartsgallery/qml/BarSeries.qml 1
 
     \beginfloatleft
     \image examples_qmlchart6.png
@@ -514,6 +515,7 @@ bool QAbstractBarSeries::insert(int index, QBarSet *set)
     if (success) {
         QList<QBarSet *> sets;
         sets.append(set);
+        set->setParent(this);
         emit barsetsAdded(sets);
         emit countChanged();
     }
@@ -923,7 +925,8 @@ QList<QLegendMarker*> QAbstractBarSeriesPrivate::createLegendMarkers(QLegend* le
     Q_Q(QAbstractBarSeries);
     QList<QLegendMarker*> markers;
 
-    foreach(QBarSet* set, q->barSets()) {
+    const auto barSets = q->barSets();
+    for (QBarSet *set : barSets) {
         QBarLegendMarker* marker = new QBarLegendMarker(q,set,legend);
         markers << marker;
     }
@@ -1045,8 +1048,8 @@ bool QAbstractBarSeriesPrivate::insert(int index, QBarSet *set)
                      this, &QAbstractBarSeriesPrivate::handleSetValueAdd);
     QObject::connect(set->d_ptr.data(), &QBarSetPrivate::valueRemoved,
                      this, &QAbstractBarSeriesPrivate::handleSetValueRemove);
-    disconnect(set, &QBarSet::selectedBarsChanged,
-               this, &QAbstractBarSeriesPrivate::updatedBars);
+    connect(set, &QBarSet::selectedBarsChanged,
+            this, &QAbstractBarSeriesPrivate::updatedBars);
 
     emit restructuredBars();      // this notifies barchartitem
     return true;
