@@ -279,7 +279,7 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \qmlproperty QVariantList BarSet::values
+    \qmlproperty list<var> BarSet::values
     The values of the bar set. You can set a list of either \l [QML]{real} or \l [QML]{point}
     types as values.
 
