@@ -26,7 +26,7 @@ class QChart;
 class ChartPresenter;
 class QChartView;
 
-class Q_CHARTS_PRIVATE_EXPORT QChartViewPrivate
+class Q_CHARTS_EXPORT QChartViewPrivate
 {
 public:
     explicit QChartViewPrivate(QChartView *q, QChart *chart = 0);
